# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import farglot.__farcaster.generated.hub_event_pb2 as hub__event__pb2
import farglot.__farcaster.generated.id_registry_event_pb2 as id__registry__event__pb2
import farglot.__farcaster.generated.message_pb2 as message__pb2
import farglot.__farcaster.generated.name_registry_event_pb2 as name__registry__event__pb2
import farglot.__farcaster.generated.onchain_event_pb2 as onchain__event__pb2
import farglot.__farcaster.generated.request_response_pb2 as request__response__pb2
import farglot.__farcaster.generated.username_proof_pb2 as username__proof__pb2


class HubServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SubmitMessage = channel.unary_unary(
            "/HubService/SubmitMessage",
            request_serializer=message__pb2.Message.SerializeToString,
            response_deserializer=message__pb2.Message.FromString,
        )
        self.Subscribe = channel.unary_stream(
            "/HubService/Subscribe",
            request_serializer=request__response__pb2.SubscribeRequest.SerializeToString,
            response_deserializer=hub__event__pb2.HubEvent.FromString,
        )
        self.GetEvent = channel.unary_unary(
            "/HubService/GetEvent",
            request_serializer=request__response__pb2.EventRequest.SerializeToString,
            response_deserializer=hub__event__pb2.HubEvent.FromString,
        )
        self.GetCast = channel.unary_unary(
            "/HubService/GetCast",
            request_serializer=message__pb2.CastId.SerializeToString,
            response_deserializer=message__pb2.Message.FromString,
        )
        self.GetCastsByFid = channel.unary_unary(
            "/HubService/GetCastsByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetCastsByParent = channel.unary_unary(
            "/HubService/GetCastsByParent",
            request_serializer=request__response__pb2.CastsByParentRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetCastsByMention = channel.unary_unary(
            "/HubService/GetCastsByMention",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetReaction = channel.unary_unary(
            "/HubService/GetReaction",
            request_serializer=request__response__pb2.ReactionRequest.SerializeToString,
            response_deserializer=message__pb2.Message.FromString,
        )
        self.GetReactionsByFid = channel.unary_unary(
            "/HubService/GetReactionsByFid",
            request_serializer=request__response__pb2.ReactionsByFidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetReactionsByCast = channel.unary_unary(
            "/HubService/GetReactionsByCast",
            request_serializer=request__response__pb2.ReactionsByTargetRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetReactionsByTarget = channel.unary_unary(
            "/HubService/GetReactionsByTarget",
            request_serializer=request__response__pb2.ReactionsByTargetRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetUserData = channel.unary_unary(
            "/HubService/GetUserData",
            request_serializer=request__response__pb2.UserDataRequest.SerializeToString,
            response_deserializer=message__pb2.Message.FromString,
        )
        self.GetUserDataByFid = channel.unary_unary(
            "/HubService/GetUserDataByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetNameRegistryEvent = channel.unary_unary(
            "/HubService/GetNameRegistryEvent",
            request_serializer=request__response__pb2.NameRegistryEventRequest.SerializeToString,
            response_deserializer=name__registry__event__pb2.NameRegistryEvent.FromString,
        )
        self.GetOnChainEvents = channel.unary_unary(
            "/HubService/GetOnChainEvents",
            request_serializer=request__response__pb2.OnChainEventRequest.SerializeToString,
            response_deserializer=request__response__pb2.OnChainEventResponse.FromString,
        )
        self.GetCurrentStorageLimitsByFid = channel.unary_unary(
            "/HubService/GetCurrentStorageLimitsByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.StorageLimitsResponse.FromString,
        )
        self.GetUsernameProof = channel.unary_unary(
            "/HubService/GetUsernameProof",
            request_serializer=request__response__pb2.UsernameProofRequest.SerializeToString,
            response_deserializer=username__proof__pb2.UserNameProof.FromString,
        )
        self.GetUserNameProofsByFid = channel.unary_unary(
            "/HubService/GetUserNameProofsByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.UsernameProofsResponse.FromString,
        )
        self.GetVerification = channel.unary_unary(
            "/HubService/GetVerification",
            request_serializer=request__response__pb2.VerificationRequest.SerializeToString,
            response_deserializer=message__pb2.Message.FromString,
        )
        self.GetVerificationsByFid = channel.unary_unary(
            "/HubService/GetVerificationsByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetSigner = channel.unary_unary(
            "/HubService/GetSigner",
            request_serializer=request__response__pb2.SignerRequest.SerializeToString,
            response_deserializer=message__pb2.Message.FromString,
        )
        self.GetOnChainSigner = channel.unary_unary(
            "/HubService/GetOnChainSigner",
            request_serializer=request__response__pb2.SignerRequest.SerializeToString,
            response_deserializer=onchain__event__pb2.OnChainEvent.FromString,
        )
        self.GetSignersByFid = channel.unary_unary(
            "/HubService/GetSignersByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetIdRegistryEvent = channel.unary_unary(
            "/HubService/GetIdRegistryEvent",
            request_serializer=request__response__pb2.IdRegistryEventRequest.SerializeToString,
            response_deserializer=id__registry__event__pb2.IdRegistryEvent.FromString,
        )
        self.GetIdRegistryEventByAddress = channel.unary_unary(
            "/HubService/GetIdRegistryEventByAddress",
            request_serializer=request__response__pb2.IdRegistryEventByAddressRequest.SerializeToString,
            response_deserializer=id__registry__event__pb2.IdRegistryEvent.FromString,
        )
        self.GetFids = channel.unary_unary(
            "/HubService/GetFids",
            request_serializer=request__response__pb2.FidsRequest.SerializeToString,
            response_deserializer=request__response__pb2.FidsResponse.FromString,
        )
        self.GetLink = channel.unary_unary(
            "/HubService/GetLink",
            request_serializer=request__response__pb2.LinkRequest.SerializeToString,
            response_deserializer=message__pb2.Message.FromString,
        )
        self.GetLinksByFid = channel.unary_unary(
            "/HubService/GetLinksByFid",
            request_serializer=request__response__pb2.LinksByFidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetLinksByTarget = channel.unary_unary(
            "/HubService/GetLinksByTarget",
            request_serializer=request__response__pb2.LinksByTargetRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetAllCastMessagesByFid = channel.unary_unary(
            "/HubService/GetAllCastMessagesByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetAllReactionMessagesByFid = channel.unary_unary(
            "/HubService/GetAllReactionMessagesByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetAllVerificationMessagesByFid = channel.unary_unary(
            "/HubService/GetAllVerificationMessagesByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetAllSignerMessagesByFid = channel.unary_unary(
            "/HubService/GetAllSignerMessagesByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetAllUserDataMessagesByFid = channel.unary_unary(
            "/HubService/GetAllUserDataMessagesByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetAllLinkMessagesByFid = channel.unary_unary(
            "/HubService/GetAllLinkMessagesByFid",
            request_serializer=request__response__pb2.FidRequest.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetInfo = channel.unary_unary(
            "/HubService/GetInfo",
            request_serializer=request__response__pb2.HubInfoRequest.SerializeToString,
            response_deserializer=request__response__pb2.HubInfoResponse.FromString,
        )
        self.GetSyncStatus = channel.unary_unary(
            "/HubService/GetSyncStatus",
            request_serializer=request__response__pb2.SyncStatusRequest.SerializeToString,
            response_deserializer=request__response__pb2.SyncStatusResponse.FromString,
        )
        self.GetAllSyncIdsByPrefix = channel.unary_unary(
            "/HubService/GetAllSyncIdsByPrefix",
            request_serializer=request__response__pb2.TrieNodePrefix.SerializeToString,
            response_deserializer=request__response__pb2.SyncIds.FromString,
        )
        self.GetAllMessagesBySyncIds = channel.unary_unary(
            "/HubService/GetAllMessagesBySyncIds",
            request_serializer=request__response__pb2.SyncIds.SerializeToString,
            response_deserializer=request__response__pb2.MessagesResponse.FromString,
        )
        self.GetSyncMetadataByPrefix = channel.unary_unary(
            "/HubService/GetSyncMetadataByPrefix",
            request_serializer=request__response__pb2.TrieNodePrefix.SerializeToString,
            response_deserializer=request__response__pb2.TrieNodeMetadataResponse.FromString,
        )
        self.GetSyncSnapshotByPrefix = channel.unary_unary(
            "/HubService/GetSyncSnapshotByPrefix",
            request_serializer=request__response__pb2.TrieNodePrefix.SerializeToString,
            response_deserializer=request__response__pb2.TrieNodeSnapshotResponse.FromString,
        )


class HubServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SubmitMessage(self, request, context):
        """Submit Methods"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Subscribe(self, request, context):
        """Event Methods"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCast(self, request, context):
        """Casts"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCastsByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCastsByParent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCastsByMention(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetReaction(self, request, context):
        """Reactions"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetReactionsByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetReactionsByCast(self, request, context):
        """To be deprecated"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetReactionsByTarget(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetUserData(self, request, context):
        """User Data"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetUserDataByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetNameRegistryEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetOnChainEvents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCurrentStorageLimitsByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetUsernameProof(self, request, context):
        """Username Proof"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetUserNameProofsByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetVerification(self, request, context):
        """Verifications"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetVerificationsByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetSigner(self, request, context):
        """Signer"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetOnChainSigner(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetSignersByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetIdRegistryEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetIdRegistryEventByAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetFids(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetLink(self, request, context):
        """Links"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetLinksByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetLinksByTarget(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetAllCastMessagesByFid(self, request, context):
        """Bulk Methods"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetAllReactionMessagesByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetAllVerificationMessagesByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetAllSignerMessagesByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetAllUserDataMessagesByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetAllLinkMessagesByFid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetInfo(self, request, context):
        """Sync Methods"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetSyncStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetAllSyncIdsByPrefix(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetAllMessagesBySyncIds(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetSyncMetadataByPrefix(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetSyncSnapshotByPrefix(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_HubServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "SubmitMessage": grpc.unary_unary_rpc_method_handler(
            servicer.SubmitMessage,
            request_deserializer=message__pb2.Message.FromString,
            response_serializer=message__pb2.Message.SerializeToString,
        ),
        "Subscribe": grpc.unary_stream_rpc_method_handler(
            servicer.Subscribe,
            request_deserializer=request__response__pb2.SubscribeRequest.FromString,
            response_serializer=hub__event__pb2.HubEvent.SerializeToString,
        ),
        "GetEvent": grpc.unary_unary_rpc_method_handler(
            servicer.GetEvent,
            request_deserializer=request__response__pb2.EventRequest.FromString,
            response_serializer=hub__event__pb2.HubEvent.SerializeToString,
        ),
        "GetCast": grpc.unary_unary_rpc_method_handler(
            servicer.GetCast,
            request_deserializer=message__pb2.CastId.FromString,
            response_serializer=message__pb2.Message.SerializeToString,
        ),
        "GetCastsByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetCastsByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetCastsByParent": grpc.unary_unary_rpc_method_handler(
            servicer.GetCastsByParent,
            request_deserializer=request__response__pb2.CastsByParentRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetCastsByMention": grpc.unary_unary_rpc_method_handler(
            servicer.GetCastsByMention,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetReaction": grpc.unary_unary_rpc_method_handler(
            servicer.GetReaction,
            request_deserializer=request__response__pb2.ReactionRequest.FromString,
            response_serializer=message__pb2.Message.SerializeToString,
        ),
        "GetReactionsByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetReactionsByFid,
            request_deserializer=request__response__pb2.ReactionsByFidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetReactionsByCast": grpc.unary_unary_rpc_method_handler(
            servicer.GetReactionsByCast,
            request_deserializer=request__response__pb2.ReactionsByTargetRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetReactionsByTarget": grpc.unary_unary_rpc_method_handler(
            servicer.GetReactionsByTarget,
            request_deserializer=request__response__pb2.ReactionsByTargetRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetUserData": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserData,
            request_deserializer=request__response__pb2.UserDataRequest.FromString,
            response_serializer=message__pb2.Message.SerializeToString,
        ),
        "GetUserDataByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserDataByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetNameRegistryEvent": grpc.unary_unary_rpc_method_handler(
            servicer.GetNameRegistryEvent,
            request_deserializer=request__response__pb2.NameRegistryEventRequest.FromString,
            response_serializer=name__registry__event__pb2.NameRegistryEvent.SerializeToString,
        ),
        "GetOnChainEvents": grpc.unary_unary_rpc_method_handler(
            servicer.GetOnChainEvents,
            request_deserializer=request__response__pb2.OnChainEventRequest.FromString,
            response_serializer=request__response__pb2.OnChainEventResponse.SerializeToString,
        ),
        "GetCurrentStorageLimitsByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetCurrentStorageLimitsByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.StorageLimitsResponse.SerializeToString,
        ),
        "GetUsernameProof": grpc.unary_unary_rpc_method_handler(
            servicer.GetUsernameProof,
            request_deserializer=request__response__pb2.UsernameProofRequest.FromString,
            response_serializer=username__proof__pb2.UserNameProof.SerializeToString,
        ),
        "GetUserNameProofsByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserNameProofsByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.UsernameProofsResponse.SerializeToString,
        ),
        "GetVerification": grpc.unary_unary_rpc_method_handler(
            servicer.GetVerification,
            request_deserializer=request__response__pb2.VerificationRequest.FromString,
            response_serializer=message__pb2.Message.SerializeToString,
        ),
        "GetVerificationsByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetVerificationsByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetSigner": grpc.unary_unary_rpc_method_handler(
            servicer.GetSigner,
            request_deserializer=request__response__pb2.SignerRequest.FromString,
            response_serializer=message__pb2.Message.SerializeToString,
        ),
        "GetOnChainSigner": grpc.unary_unary_rpc_method_handler(
            servicer.GetOnChainSigner,
            request_deserializer=request__response__pb2.SignerRequest.FromString,
            response_serializer=onchain__event__pb2.OnChainEvent.SerializeToString,
        ),
        "GetSignersByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetSignersByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetIdRegistryEvent": grpc.unary_unary_rpc_method_handler(
            servicer.GetIdRegistryEvent,
            request_deserializer=request__response__pb2.IdRegistryEventRequest.FromString,
            response_serializer=id__registry__event__pb2.IdRegistryEvent.SerializeToString,
        ),
        "GetIdRegistryEventByAddress": grpc.unary_unary_rpc_method_handler(
            servicer.GetIdRegistryEventByAddress,
            request_deserializer=request__response__pb2.IdRegistryEventByAddressRequest.FromString,
            response_serializer=id__registry__event__pb2.IdRegistryEvent.SerializeToString,
        ),
        "GetFids": grpc.unary_unary_rpc_method_handler(
            servicer.GetFids,
            request_deserializer=request__response__pb2.FidsRequest.FromString,
            response_serializer=request__response__pb2.FidsResponse.SerializeToString,
        ),
        "GetLink": grpc.unary_unary_rpc_method_handler(
            servicer.GetLink,
            request_deserializer=request__response__pb2.LinkRequest.FromString,
            response_serializer=message__pb2.Message.SerializeToString,
        ),
        "GetLinksByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetLinksByFid,
            request_deserializer=request__response__pb2.LinksByFidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetLinksByTarget": grpc.unary_unary_rpc_method_handler(
            servicer.GetLinksByTarget,
            request_deserializer=request__response__pb2.LinksByTargetRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetAllCastMessagesByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetAllCastMessagesByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetAllReactionMessagesByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetAllReactionMessagesByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetAllVerificationMessagesByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetAllVerificationMessagesByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetAllSignerMessagesByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetAllSignerMessagesByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetAllUserDataMessagesByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetAllUserDataMessagesByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetAllLinkMessagesByFid": grpc.unary_unary_rpc_method_handler(
            servicer.GetAllLinkMessagesByFid,
            request_deserializer=request__response__pb2.FidRequest.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetInfo": grpc.unary_unary_rpc_method_handler(
            servicer.GetInfo,
            request_deserializer=request__response__pb2.HubInfoRequest.FromString,
            response_serializer=request__response__pb2.HubInfoResponse.SerializeToString,
        ),
        "GetSyncStatus": grpc.unary_unary_rpc_method_handler(
            servicer.GetSyncStatus,
            request_deserializer=request__response__pb2.SyncStatusRequest.FromString,
            response_serializer=request__response__pb2.SyncStatusResponse.SerializeToString,
        ),
        "GetAllSyncIdsByPrefix": grpc.unary_unary_rpc_method_handler(
            servicer.GetAllSyncIdsByPrefix,
            request_deserializer=request__response__pb2.TrieNodePrefix.FromString,
            response_serializer=request__response__pb2.SyncIds.SerializeToString,
        ),
        "GetAllMessagesBySyncIds": grpc.unary_unary_rpc_method_handler(
            servicer.GetAllMessagesBySyncIds,
            request_deserializer=request__response__pb2.SyncIds.FromString,
            response_serializer=request__response__pb2.MessagesResponse.SerializeToString,
        ),
        "GetSyncMetadataByPrefix": grpc.unary_unary_rpc_method_handler(
            servicer.GetSyncMetadataByPrefix,
            request_deserializer=request__response__pb2.TrieNodePrefix.FromString,
            response_serializer=request__response__pb2.TrieNodeMetadataResponse.SerializeToString,
        ),
        "GetSyncSnapshotByPrefix": grpc.unary_unary_rpc_method_handler(
            servicer.GetSyncSnapshotByPrefix,
            request_deserializer=request__response__pb2.TrieNodePrefix.FromString,
            response_serializer=request__response__pb2.TrieNodeSnapshotResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "HubService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class HubService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SubmitMessage(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/SubmitMessage",
            message__pb2.Message.SerializeToString,
            message__pb2.Message.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Subscribe(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/HubService/Subscribe",
            request__response__pb2.SubscribeRequest.SerializeToString,
            hub__event__pb2.HubEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetEvent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetEvent",
            request__response__pb2.EventRequest.SerializeToString,
            hub__event__pb2.HubEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetCast(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetCast",
            message__pb2.CastId.SerializeToString,
            message__pb2.Message.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetCastsByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetCastsByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetCastsByParent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetCastsByParent",
            request__response__pb2.CastsByParentRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetCastsByMention(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetCastsByMention",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetReaction(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetReaction",
            request__response__pb2.ReactionRequest.SerializeToString,
            message__pb2.Message.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetReactionsByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetReactionsByFid",
            request__response__pb2.ReactionsByFidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetReactionsByCast(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetReactionsByCast",
            request__response__pb2.ReactionsByTargetRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetReactionsByTarget(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetReactionsByTarget",
            request__response__pb2.ReactionsByTargetRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetUserData(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetUserData",
            request__response__pb2.UserDataRequest.SerializeToString,
            message__pb2.Message.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetUserDataByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetUserDataByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetNameRegistryEvent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetNameRegistryEvent",
            request__response__pb2.NameRegistryEventRequest.SerializeToString,
            name__registry__event__pb2.NameRegistryEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetOnChainEvents(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetOnChainEvents",
            request__response__pb2.OnChainEventRequest.SerializeToString,
            request__response__pb2.OnChainEventResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetCurrentStorageLimitsByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetCurrentStorageLimitsByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.StorageLimitsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetUsernameProof(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetUsernameProof",
            request__response__pb2.UsernameProofRequest.SerializeToString,
            username__proof__pb2.UserNameProof.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetUserNameProofsByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetUserNameProofsByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.UsernameProofsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetVerification(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetVerification",
            request__response__pb2.VerificationRequest.SerializeToString,
            message__pb2.Message.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetVerificationsByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetVerificationsByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetSigner(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetSigner",
            request__response__pb2.SignerRequest.SerializeToString,
            message__pb2.Message.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetOnChainSigner(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetOnChainSigner",
            request__response__pb2.SignerRequest.SerializeToString,
            onchain__event__pb2.OnChainEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetSignersByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetSignersByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetIdRegistryEvent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetIdRegistryEvent",
            request__response__pb2.IdRegistryEventRequest.SerializeToString,
            id__registry__event__pb2.IdRegistryEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetIdRegistryEventByAddress(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetIdRegistryEventByAddress",
            request__response__pb2.IdRegistryEventByAddressRequest.SerializeToString,
            id__registry__event__pb2.IdRegistryEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetFids(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetFids",
            request__response__pb2.FidsRequest.SerializeToString,
            request__response__pb2.FidsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetLink(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetLink",
            request__response__pb2.LinkRequest.SerializeToString,
            message__pb2.Message.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetLinksByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetLinksByFid",
            request__response__pb2.LinksByFidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetLinksByTarget(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetLinksByTarget",
            request__response__pb2.LinksByTargetRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetAllCastMessagesByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetAllCastMessagesByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetAllReactionMessagesByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetAllReactionMessagesByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetAllVerificationMessagesByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetAllVerificationMessagesByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetAllSignerMessagesByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetAllSignerMessagesByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetAllUserDataMessagesByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetAllUserDataMessagesByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetAllLinkMessagesByFid(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetAllLinkMessagesByFid",
            request__response__pb2.FidRequest.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetInfo",
            request__response__pb2.HubInfoRequest.SerializeToString,
            request__response__pb2.HubInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetSyncStatus(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetSyncStatus",
            request__response__pb2.SyncStatusRequest.SerializeToString,
            request__response__pb2.SyncStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetAllSyncIdsByPrefix(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetAllSyncIdsByPrefix",
            request__response__pb2.TrieNodePrefix.SerializeToString,
            request__response__pb2.SyncIds.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetAllMessagesBySyncIds(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetAllMessagesBySyncIds",
            request__response__pb2.SyncIds.SerializeToString,
            request__response__pb2.MessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetSyncMetadataByPrefix(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetSyncMetadataByPrefix",
            request__response__pb2.TrieNodePrefix.SerializeToString,
            request__response__pb2.TrieNodeMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetSyncSnapshotByPrefix(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HubService/GetSyncSnapshotByPrefix",
            request__response__pb2.TrieNodePrefix.SerializeToString,
            request__response__pb2.TrieNodeSnapshotResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class AdminServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RebuildSyncTrie = channel.unary_unary(
            "/AdminService/RebuildSyncTrie",
            request_serializer=request__response__pb2.Empty.SerializeToString,
            response_deserializer=request__response__pb2.Empty.FromString,
        )
        self.DeleteAllMessagesFromDb = channel.unary_unary(
            "/AdminService/DeleteAllMessagesFromDb",
            request_serializer=request__response__pb2.Empty.SerializeToString,
            response_deserializer=request__response__pb2.Empty.FromString,
        )
        self.SubmitIdRegistryEvent = channel.unary_unary(
            "/AdminService/SubmitIdRegistryEvent",
            request_serializer=id__registry__event__pb2.IdRegistryEvent.SerializeToString,
            response_deserializer=id__registry__event__pb2.IdRegistryEvent.FromString,
        )
        self.SubmitNameRegistryEvent = channel.unary_unary(
            "/AdminService/SubmitNameRegistryEvent",
            request_serializer=name__registry__event__pb2.NameRegistryEvent.SerializeToString,
            response_deserializer=name__registry__event__pb2.NameRegistryEvent.FromString,
        )
        self.SubmitOnChainEvent = channel.unary_unary(
            "/AdminService/SubmitOnChainEvent",
            request_serializer=onchain__event__pb2.OnChainEvent.SerializeToString,
            response_deserializer=onchain__event__pb2.OnChainEvent.FromString,
        )


class AdminServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RebuildSyncTrie(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteAllMessagesFromDb(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SubmitIdRegistryEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SubmitNameRegistryEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SubmitOnChainEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AdminServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "RebuildSyncTrie": grpc.unary_unary_rpc_method_handler(
            servicer.RebuildSyncTrie,
            request_deserializer=request__response__pb2.Empty.FromString,
            response_serializer=request__response__pb2.Empty.SerializeToString,
        ),
        "DeleteAllMessagesFromDb": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteAllMessagesFromDb,
            request_deserializer=request__response__pb2.Empty.FromString,
            response_serializer=request__response__pb2.Empty.SerializeToString,
        ),
        "SubmitIdRegistryEvent": grpc.unary_unary_rpc_method_handler(
            servicer.SubmitIdRegistryEvent,
            request_deserializer=id__registry__event__pb2.IdRegistryEvent.FromString,
            response_serializer=id__registry__event__pb2.IdRegistryEvent.SerializeToString,
        ),
        "SubmitNameRegistryEvent": grpc.unary_unary_rpc_method_handler(
            servicer.SubmitNameRegistryEvent,
            request_deserializer=name__registry__event__pb2.NameRegistryEvent.FromString,
            response_serializer=name__registry__event__pb2.NameRegistryEvent.SerializeToString,
        ),
        "SubmitOnChainEvent": grpc.unary_unary_rpc_method_handler(
            servicer.SubmitOnChainEvent,
            request_deserializer=onchain__event__pb2.OnChainEvent.FromString,
            response_serializer=onchain__event__pb2.OnChainEvent.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "AdminService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class AdminService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RebuildSyncTrie(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/AdminService/RebuildSyncTrie",
            request__response__pb2.Empty.SerializeToString,
            request__response__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteAllMessagesFromDb(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/AdminService/DeleteAllMessagesFromDb",
            request__response__pb2.Empty.SerializeToString,
            request__response__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SubmitIdRegistryEvent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/AdminService/SubmitIdRegistryEvent",
            id__registry__event__pb2.IdRegistryEvent.SerializeToString,
            id__registry__event__pb2.IdRegistryEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SubmitNameRegistryEvent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/AdminService/SubmitNameRegistryEvent",
            name__registry__event__pb2.NameRegistryEvent.SerializeToString,
            name__registry__event__pb2.NameRegistryEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SubmitOnChainEvent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/AdminService/SubmitOnChainEvent",
            onchain__event__pb2.OnChainEvent.SerializeToString,
            onchain__event__pb2.OnChainEvent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: username_proof.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14username_proof.proto\"|\n\rUserNameProof\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\x0c\x12\r\n\x05owner\x18\x03 \x01(\x0c\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x12\x0b\n\x03\x66id\x18\x05 \x01(\x04\x12\x1b\n\x04type\x18\x06 \x01(\x0e\x32\r.UserNameType*Y\n\x0cUserNameType\x12\x16\n\x12USERNAME_TYPE_NONE\x10\x00\x12\x17\n\x13USERNAME_TYPE_FNAME\x10\x01\x12\x18\n\x14USERNAME_TYPE_ENS_L1\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'username_proof_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_USERNAMETYPE']._serialized_start=150
  _globals['_USERNAMETYPE']._serialized_end=239
  _globals['_USERNAMEPROOF']._serialized_start=24
  _globals['_USERNAMEPROOF']._serialized_end=148
# @@protoc_insertion_point(module_scope)



from typing_extensions import Self
from typing import List, Optional
from transformers import (
    AutoModelForTokenClassification,
    PretrainedConfig,
)

from farglot.analyzer.base import BaseAnalyzer
from farglot.pretrained import load_model_and_tokenizer


class AnalyzerForTokenClassification(BaseAnalyzer):
    @classmethod
    def from_model_name(
        cls, model_name: str, config: Optional[PretrainedConfig] = None
    ) -> Self:
        model, tokenizer = load_model_and_tokenizer(
            base_model=model_name,
            auto_model_class=AutoModelForTokenClassification,
            config=config,
        )
        return cls(model, tokenizer)

    def predict(self, inputs: List[str]):
        raise NotImplementedError(
            "predict not implemented for AnalyzerForTokenClassification"
        )



from farglot.analyzer.base import BaseAnalyzer
from farglot.analyzer.cast import CastAnalyzer
from farglot.analyzer.sequence_classification import AnalyzerForSequenceClassification
from farglot.analyzer.token_classification import AnalyzerForTokenClassification
from farglot.pretrained import load_model_and_tokenizer

__all__ = [
    "BaseAnalyzer",
    "CastAnalyzer",
    "AnalyzerForSequenceClassification",
    "AnalyzerForTokenClassification",
    "load_model_and_tokenizer",
]



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['examples',
 'examples.classifiers',
 'farglot',
 'farglot.__farcaster',
 'farglot.__farcaster.generated',
 'farglot.analyzer']

package_data = \
{'': ['*']}

install_requires = \
['datasets>=2.14.3,<3.0.0',
 'torch>=2.0.1,<3.0.0',
 'transformers>=4.31.0,<5.0.0']

extras_require = \
{':extra == "cli"': ['grpcio==1.53.0', 'protobuf==4.22.1'],
 'cli': ['typer[all]>=0.9.0,<0.10.0',
         'PyNaCl>=1.5.0,<2.0.0',
         'blake3>=0.3.3,<0.4.0',
         'faust-streaming-rocksdb>=0.9.2,<0.10.0']}

entry_points = \
{'console_scripts': ['farglot = farglot.cli:app']}

setup_kwargs = {
    'name': 'farglot',
    'version': '0.1.3',
    'description': 'A Transformer-based SocialNLP toolkit for Farcaster',
    'long_description': '# FarGlot\n\nA Transformer-based SocialNLP toolkit for [Farcaster](https://www.farcaster.xyz/).\n\n## Installation\n\n```\npip install farglot\n```\n\n## Examples\n\n```python\nfrom farglot import CastAnalyzer\n\nsentiment_analyzer=CastAnalyzer.sequence_analzyer_from_model_name(\n    hub_address="nemes.farcaster.xyz:2283",\n    model_name="pysentimiento/robertuito-sentiment-analysis"\n)\n\nsentiment_analyzer.predict_cast(fid=2, hash_hex="0bcdcbf006ec22b79f37f2cf2a09c33413883937")\n# {\'NEG\': 0.051998768001794815, \'NEU\': 0.22470703721046448, \'POS\': 0.7232941389083862}\nsentiment_analyzer.predict_casts_by_fid(fid=2)\n# {\'NEG\': 0.03734538331627846, \'NEU\': 0.505352795124054, \'POS\': 0.4573018550872803}\n```\n\n## Generate a Training Corpus from a [Hub](https://github.com/farcasterxyz/hub-monorepo/tree/main/apps/hubble)\n\n### Install the FarGlot CLI\n\n```\npip install "farglot[cli]"\n```\n\n### Define Training Set Classifier(s)\n\n```json\n{\n  "name": "labels",\n  "default_value": 1 // optional\n}\n```\n\nFor multi-label classfication:\n\n```json\n[\n  {\n    "name": "class_one",\n    "default_value": 1 // optional\n  },\n  {\n    "name": "class_two",\n    "default_value": 2 // optional\n  },\n  {\n    "name": "class_three",\n    "default_value": 3 // optional\n  }\n]\n```\n\n### Usage\n\n```sh\nfarglot init\nfarglot set-classifers-path /path/to/class_configs.json\nfarglot set-hub-db-path /path/to/.rocks/rocks.hub._default\nfarglot new-training-set --out ./data/training-set.csv\n```\n\n### Tuning\n\nTODO: Example of fine-tuning and uploading dataset and model to [Hugging Face](https://huggingface.co/)\n\n### Tuning Resources\n\nNot sure how to where to start? Check out the following blog posts on tuning an LLM:\n\n- [Datasets and Preprocessing](https://michaelhly.com/posts/tune-llm-one)\n- [Hyperparameters and Metrics](https://michaelhly.com/posts/tune-llm-two)\n\nThis largely is largely adapted off of [pysentimiento](https://github.com/pysentimiento/pysentimiento).\n',
    'author': 'michaelhly',
    'author_email': 'michaelhly@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/michaelhly/FarGlot',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<3.11',
}


setup(**setup_kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tjob.proto\"?\n RevokeMessagesBySignerJobPayload\x12\x0b\n\x03\x66id\x18\x01 \x01(\r\x12\x0e\n\x06signer\x18\x02 \x01(\x0c\"8\n\'UpdateNameRegistryEventExpiryJobPayload\x12\r\n\x05\x66name\x18\x01 \x01(\x0c\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_REVOKEMESSAGESBYSIGNERJOBPAYLOAD']._serialized_start=13
  _globals['_REVOKEMESSAGESBYSIGNERJOBPAYLOAD']._serialized_end=76
  _globals['_UPDATENAMEREGISTRYEVENTEXPIRYJOBPAYLOAD']._serialized_start=78
  _globals['_UPDATENAMEREGISTRYEVENTEXPIRYJOBPAYLOAD']._serialized_end=134
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from typing import List, Optional
from typing_extensions import Self
from transformers import PretrainedConfig


class BaseAnalyzer(ABC):
    @classmethod
    @abstractmethod
    def from_model_name(
        cls, model_name: str, config: Optional[PretrainedConfig] = None
    ) -> Self:
        raise NotImplementedError("from_model_name not implemented for BaseAnalyzer")

    @abstractmethod
    def predict(self, inputs: List[str]) -> bytes:
        raise NotImplementedError("predict not implemented for BaseAnalyzer")



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DbTrieNode(_message.Message):
    __slots__ = ["key", "childChars", "items", "hash"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    CHILDCHARS_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    childChars: _containers.RepeatedScalarFieldContainer[int]
    items: int
    hash: bytes
    def __init__(self, key: _Optional[bytes] = ..., childChars: _Optional[_Iterable[int]] = ..., items: _Optional[int] = ..., hash: _Optional[bytes] = ...) -> None: ...



from abc import ABC, abstractmethod

from eth_account import Account
from eth_account.messages import encode_structured_data
from nacl.signing import SigningKey
from nacl.encoding import RawEncoder

from farcaster.generated.message_pb2 import SignatureScheme


class Signer(ABC):
    @abstractmethod
    def public_key(self) -> bytes:
        pass

    @abstractmethod
    def private_key(self) -> bytes:
        pass

    @abstractmethod
    def signature_scheme(self) -> SignatureScheme:
        pass

    @abstractmethod
    def sign_hash(self, hash: bytes) -> bytes:
        pass

    @classmethod
    @abstractmethod
    def generate(cls) -> "Signer":
        pass


class EIP712Signer(Signer):
    def __init__(self, account: Account) -> None:
        self.account = account

    def public_key(self) -> bytes:
        return bytes.fromhex(self.account.address[2:])

    def private_key(self) -> bytes:
        return self.account.key

    def signature_scheme(self) -> SignatureScheme:
        return SignatureScheme.SIGNATURE_SCHEME_EIP712

    def sign_hash(self, hash: bytes) -> bytes:
        eip712_schema = {
            "types": {
                "EIP712Domain": [
                    {"name": "name", "type": "string"},
                    {"name": "version", "type": "string"},
                    {"name": "salt", "type": "bytes32"},
                ],
                "MessageData": [
                    {"name": "hash", "type": "bytes"},
                ],
            },
            "domain": {
                "name": "Farcaster Verify Ethereum Address",
                "version": "2.0.0",
                # fixed salt to minimize collisions, should be the same as
                # packages/core/src/crypto/eip712.ts in @farcaster/hub-monorepo
                "salt": bytes.fromhex(
                    "f2d857f4a3edcb9b78b4d503bfe733db1e3f6cdc2b7971ee739626c97e86a558"
                ),
            },
            "primaryType": "MessageData",
            "message": {
                "hash": hash,
            },
        }

        encoded_message = encode_structured_data(eip712_schema)
        signature = self.account.sign_message(encoded_message)
        return bytes(signature.signature)

    @classmethod
    def generate(cls) -> "EIP712Signer":
        return cls(Account.create())


class Ed25519Signer(Signer):
    def __init__(self, signing_key: SigningKey) -> None:
        self.signing_key = signing_key

    def public_key(self, encoder=RawEncoder) -> bytes:
        return self.signing_key.verify_key.encode(encoder=encoder)

    def private_key(self, encoder=RawEncoder) -> bytes:
        return self.signing_key.encode(encoder=encoder)

    def signature_scheme(self) -> SignatureScheme:
        return SignatureScheme.SIGNATURE_SCHEME_ED25519

    def sign_hash(self, hash: bytes) -> bytes:
        return self.signing_key.sign(hash).signature

    @classmethod
    def generate(cls) -> "Ed25519Signer":
        return cls(SigningKey.generate())



import farglot.__farcaster.generated.message_pb2 as _message_pb2
import farglot.__farcaster.generated.id_registry_event_pb2 as _id_registry_event_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class GossipVersion(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    GOSSIP_VERSION_V1: _ClassVar[GossipVersion]
    GOSSIP_VERSION_V1_1: _ClassVar[GossipVersion]

GOSSIP_VERSION_V1: GossipVersion
GOSSIP_VERSION_V1_1: GossipVersion

class GossipAddressInfo(_message.Message):
    __slots__ = ["address", "family", "port", "dns_name"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    FAMILY_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    DNS_NAME_FIELD_NUMBER: _ClassVar[int]
    address: str
    family: int
    port: int
    dns_name: str
    def __init__(
        self,
        address: _Optional[str] = ...,
        family: _Optional[int] = ...,
        port: _Optional[int] = ...,
        dns_name: _Optional[str] = ...,
    ) -> None: ...

class ContactInfoContent(_message.Message):
    __slots__ = [
        "gossip_address",
        "rpc_address",
        "excluded_hashes",
        "count",
        "hub_version",
        "network",
        "app_version",
    ]
    GOSSIP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    RPC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    EXCLUDED_HASHES_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    HUB_VERSION_FIELD_NUMBER: _ClassVar[int]
    NETWORK_FIELD_NUMBER: _ClassVar[int]
    APP_VERSION_FIELD_NUMBER: _ClassVar[int]
    gossip_address: GossipAddressInfo
    rpc_address: GossipAddressInfo
    excluded_hashes: _containers.RepeatedScalarFieldContainer[str]
    count: int
    hub_version: str
    network: _message_pb2.FarcasterNetwork
    app_version: str
    def __init__(
        self,
        gossip_address: _Optional[_Union[GossipAddressInfo, _Mapping]] = ...,
        rpc_address: _Optional[_Union[GossipAddressInfo, _Mapping]] = ...,
        excluded_hashes: _Optional[_Iterable[str]] = ...,
        count: _Optional[int] = ...,
        hub_version: _Optional[str] = ...,
        network: _Optional[_Union[_message_pb2.FarcasterNetwork, str]] = ...,
        app_version: _Optional[str] = ...,
    ) -> None: ...

class PingMessageBody(_message.Message):
    __slots__ = ["ping_origin_peer_id", "ping_timestamp"]
    PING_ORIGIN_PEER_ID_FIELD_NUMBER: _ClassVar[int]
    PING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ping_origin_peer_id: bytes
    ping_timestamp: int
    def __init__(
        self,
        ping_origin_peer_id: _Optional[bytes] = ...,
        ping_timestamp: _Optional[int] = ...,
    ) -> None: ...

class AckMessageBody(_message.Message):
    __slots__ = [
        "ping_origin_peer_id",
        "ack_origin_peer_id",
        "ping_timestamp",
        "ack_timestamp",
    ]
    PING_ORIGIN_PEER_ID_FIELD_NUMBER: _ClassVar[int]
    ACK_ORIGIN_PEER_ID_FIELD_NUMBER: _ClassVar[int]
    PING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ACK_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ping_origin_peer_id: bytes
    ack_origin_peer_id: bytes
    ping_timestamp: int
    ack_timestamp: int
    def __init__(
        self,
        ping_origin_peer_id: _Optional[bytes] = ...,
        ack_origin_peer_id: _Optional[bytes] = ...,
        ping_timestamp: _Optional[int] = ...,
        ack_timestamp: _Optional[int] = ...,
    ) -> None: ...

class NetworkLatencyMessage(_message.Message):
    __slots__ = ["ping_message", "ack_message"]
    PING_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ACK_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ping_message: PingMessageBody
    ack_message: AckMessageBody
    def __init__(
        self,
        ping_message: _Optional[_Union[PingMessageBody, _Mapping]] = ...,
        ack_message: _Optional[_Union[AckMessageBody, _Mapping]] = ...,
    ) -> None: ...

class GossipMessage(_message.Message):
    __slots__ = [
        "message",
        "id_registry_event",
        "contact_info_content",
        "network_latency_message",
        "topics",
        "peer_id",
        "version",
    ]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ID_REGISTRY_EVENT_FIELD_NUMBER: _ClassVar[int]
    CONTACT_INFO_CONTENT_FIELD_NUMBER: _ClassVar[int]
    NETWORK_LATENCY_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    PEER_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    message: _message_pb2.Message
    id_registry_event: _id_registry_event_pb2.IdRegistryEvent
    contact_info_content: ContactInfoContent
    network_latency_message: NetworkLatencyMessage
    topics: _containers.RepeatedScalarFieldContainer[str]
    peer_id: bytes
    version: GossipVersion
    def __init__(
        self,
        message: _Optional[_Union[_message_pb2.Message, _Mapping]] = ...,
        id_registry_event: _Optional[
            _Union[_id_registry_event_pb2.IdRegistryEvent, _Mapping]
        ] = ...,
        contact_info_content: _Optional[_Union[ContactInfoContent, _Mapping]] = ...,
        network_latency_message: _Optional[
            _Union[NetworkLatencyMessage, _Mapping]
        ] = ...,
        topics: _Optional[_Iterable[str]] = ...,
        peer_id: _Optional[bytes] = ...,
        version: _Optional[_Union[GossipVersion, str]] = ...,
    ) -> None: ...



import farglot.__farcaster.generated.message_pb2 as _message_pb2
import farglot.__farcaster.generated.onchain_event_pb2 as _onchain_event_pb2
import farglot.__farcaster.generated.hub_event_pb2 as _hub_event_pb2
import farglot.__farcaster.generated.username_proof_pb2 as _username_proof_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class StoreType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    STORE_TYPE_NONE: _ClassVar[StoreType]
    STORE_TYPE_CASTS: _ClassVar[StoreType]
    STORE_TYPE_LINKS: _ClassVar[StoreType]
    STORE_TYPE_REACTIONS: _ClassVar[StoreType]
    STORE_TYPE_USER_DATA: _ClassVar[StoreType]
    STORE_TYPE_VERIFICATIONS: _ClassVar[StoreType]

STORE_TYPE_NONE: StoreType
STORE_TYPE_CASTS: StoreType
STORE_TYPE_LINKS: StoreType
STORE_TYPE_REACTIONS: StoreType
STORE_TYPE_USER_DATA: StoreType
STORE_TYPE_VERIFICATIONS: StoreType

class Empty(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SubscribeRequest(_message.Message):
    __slots__ = ["event_types", "from_id"]
    EVENT_TYPES_FIELD_NUMBER: _ClassVar[int]
    FROM_ID_FIELD_NUMBER: _ClassVar[int]
    event_types: _containers.RepeatedScalarFieldContainer[_hub_event_pb2.HubEventType]
    from_id: int
    def __init__(
        self,
        event_types: _Optional[
            _Iterable[_Union[_hub_event_pb2.HubEventType, str]]
        ] = ...,
        from_id: _Optional[int] = ...,
    ) -> None: ...

class EventRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class HubInfoRequest(_message.Message):
    __slots__ = ["db_stats"]
    DB_STATS_FIELD_NUMBER: _ClassVar[int]
    db_stats: bool
    def __init__(self, db_stats: bool = ...) -> None: ...

class HubInfoResponse(_message.Message):
    __slots__ = ["version", "is_syncing", "nickname", "root_hash", "db_stats"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    IS_SYNCING_FIELD_NUMBER: _ClassVar[int]
    NICKNAME_FIELD_NUMBER: _ClassVar[int]
    ROOT_HASH_FIELD_NUMBER: _ClassVar[int]
    DB_STATS_FIELD_NUMBER: _ClassVar[int]
    version: str
    is_syncing: bool
    nickname: str
    root_hash: str
    db_stats: DbStats
    def __init__(
        self,
        version: _Optional[str] = ...,
        is_syncing: bool = ...,
        nickname: _Optional[str] = ...,
        root_hash: _Optional[str] = ...,
        db_stats: _Optional[_Union[DbStats, _Mapping]] = ...,
    ) -> None: ...

class DbStats(_message.Message):
    __slots__ = ["num_messages", "num_fid_events", "num_fname_events"]
    NUM_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    NUM_FID_EVENTS_FIELD_NUMBER: _ClassVar[int]
    NUM_FNAME_EVENTS_FIELD_NUMBER: _ClassVar[int]
    num_messages: int
    num_fid_events: int
    num_fname_events: int
    def __init__(
        self,
        num_messages: _Optional[int] = ...,
        num_fid_events: _Optional[int] = ...,
        num_fname_events: _Optional[int] = ...,
    ) -> None: ...

class SyncStatusRequest(_message.Message):
    __slots__ = ["peerId"]
    PEERID_FIELD_NUMBER: _ClassVar[int]
    peerId: str
    def __init__(self, peerId: _Optional[str] = ...) -> None: ...

class SyncStatusResponse(_message.Message):
    __slots__ = ["is_syncing", "sync_status", "engine_started"]
    IS_SYNCING_FIELD_NUMBER: _ClassVar[int]
    SYNC_STATUS_FIELD_NUMBER: _ClassVar[int]
    ENGINE_STARTED_FIELD_NUMBER: _ClassVar[int]
    is_syncing: bool
    sync_status: _containers.RepeatedCompositeFieldContainer[SyncStatus]
    engine_started: bool
    def __init__(
        self,
        is_syncing: bool = ...,
        sync_status: _Optional[_Iterable[_Union[SyncStatus, _Mapping]]] = ...,
        engine_started: bool = ...,
    ) -> None: ...

class SyncStatus(_message.Message):
    __slots__ = [
        "peerId",
        "inSync",
        "shouldSync",
        "divergencePrefix",
        "divergenceSecondsAgo",
        "theirMessages",
        "ourMessages",
        "lastBadSync",
    ]
    PEERID_FIELD_NUMBER: _ClassVar[int]
    INSYNC_FIELD_NUMBER: _ClassVar[int]
    SHOULDSYNC_FIELD_NUMBER: _ClassVar[int]
    DIVERGENCEPREFIX_FIELD_NUMBER: _ClassVar[int]
    DIVERGENCESECONDSAGO_FIELD_NUMBER: _ClassVar[int]
    THEIRMESSAGES_FIELD_NUMBER: _ClassVar[int]
    OURMESSAGES_FIELD_NUMBER: _ClassVar[int]
    LASTBADSYNC_FIELD_NUMBER: _ClassVar[int]
    peerId: str
    inSync: str
    shouldSync: bool
    divergencePrefix: str
    divergenceSecondsAgo: int
    theirMessages: int
    ourMessages: int
    lastBadSync: int
    def __init__(
        self,
        peerId: _Optional[str] = ...,
        inSync: _Optional[str] = ...,
        shouldSync: bool = ...,
        divergencePrefix: _Optional[str] = ...,
        divergenceSecondsAgo: _Optional[int] = ...,
        theirMessages: _Optional[int] = ...,
        ourMessages: _Optional[int] = ...,
        lastBadSync: _Optional[int] = ...,
    ) -> None: ...

class TrieNodeMetadataResponse(_message.Message):
    __slots__ = ["prefix", "num_messages", "hash", "children"]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    NUM_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    prefix: bytes
    num_messages: int
    hash: str
    children: _containers.RepeatedCompositeFieldContainer[TrieNodeMetadataResponse]
    def __init__(
        self,
        prefix: _Optional[bytes] = ...,
        num_messages: _Optional[int] = ...,
        hash: _Optional[str] = ...,
        children: _Optional[
            _Iterable[_Union[TrieNodeMetadataResponse, _Mapping]]
        ] = ...,
    ) -> None: ...

class TrieNodeSnapshotResponse(_message.Message):
    __slots__ = ["prefix", "excluded_hashes", "num_messages", "root_hash"]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    EXCLUDED_HASHES_FIELD_NUMBER: _ClassVar[int]
    NUM_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    ROOT_HASH_FIELD_NUMBER: _ClassVar[int]
    prefix: bytes
    excluded_hashes: _containers.RepeatedScalarFieldContainer[str]
    num_messages: int
    root_hash: str
    def __init__(
        self,
        prefix: _Optional[bytes] = ...,
        excluded_hashes: _Optional[_Iterable[str]] = ...,
        num_messages: _Optional[int] = ...,
        root_hash: _Optional[str] = ...,
    ) -> None: ...

class TrieNodePrefix(_message.Message):
    __slots__ = ["prefix"]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    prefix: bytes
    def __init__(self, prefix: _Optional[bytes] = ...) -> None: ...

class SyncIds(_message.Message):
    __slots__ = ["sync_ids"]
    SYNC_IDS_FIELD_NUMBER: _ClassVar[int]
    sync_ids: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, sync_ids: _Optional[_Iterable[bytes]] = ...) -> None: ...

class FidRequest(_message.Message):
    __slots__ = ["fid", "page_size", "page_token", "reverse"]
    FID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REVERSE_FIELD_NUMBER: _ClassVar[int]
    fid: int
    page_size: int
    page_token: bytes
    reverse: bool
    def __init__(
        self,
        fid: _Optional[int] = ...,
        page_size: _Optional[int] = ...,
        page_token: _Optional[bytes] = ...,
        reverse: bool = ...,
    ) -> None: ...

class FidsRequest(_message.Message):
    __slots__ = ["page_size", "page_token", "reverse"]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REVERSE_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: bytes
    reverse: bool
    def __init__(
        self,
        page_size: _Optional[int] = ...,
        page_token: _Optional[bytes] = ...,
        reverse: bool = ...,
    ) -> None: ...

class FidsResponse(_message.Message):
    __slots__ = ["fids", "next_page_token"]
    FIDS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    fids: _containers.RepeatedScalarFieldContainer[int]
    next_page_token: bytes
    def __init__(
        self,
        fids: _Optional[_Iterable[int]] = ...,
        next_page_token: _Optional[bytes] = ...,
    ) -> None: ...

class MessagesResponse(_message.Message):
    __slots__ = ["messages", "next_page_token"]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedCompositeFieldContainer[_message_pb2.Message]
    next_page_token: bytes
    def __init__(
        self,
        messages: _Optional[_Iterable[_Union[_message_pb2.Message, _Mapping]]] = ...,
        next_page_token: _Optional[bytes] = ...,
    ) -> None: ...

class CastsByParentRequest(_message.Message):
    __slots__ = ["parent_cast_id", "parent_url", "page_size", "page_token", "reverse"]
    PARENT_CAST_ID_FIELD_NUMBER: _ClassVar[int]
    PARENT_URL_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REVERSE_FIELD_NUMBER: _ClassVar[int]
    parent_cast_id: _message_pb2.CastId
    parent_url: str
    page_size: int
    page_token: bytes
    reverse: bool
    def __init__(
        self,
        parent_cast_id: _Optional[_Union[_message_pb2.CastId, _Mapping]] = ...,
        parent_url: _Optional[str] = ...,
        page_size: _Optional[int] = ...,
        page_token: _Optional[bytes] = ...,
        reverse: bool = ...,
    ) -> None: ...

class ReactionRequest(_message.Message):
    __slots__ = ["fid", "reaction_type", "target_cast_id", "target_url"]
    FID_FIELD_NUMBER: _ClassVar[int]
    REACTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    TARGET_CAST_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_URL_FIELD_NUMBER: _ClassVar[int]
    fid: int
    reaction_type: _message_pb2.ReactionType
    target_cast_id: _message_pb2.CastId
    target_url: str
    def __init__(
        self,
        fid: _Optional[int] = ...,
        reaction_type: _Optional[_Union[_message_pb2.ReactionType, str]] = ...,
        target_cast_id: _Optional[_Union[_message_pb2.CastId, _Mapping]] = ...,
        target_url: _Optional[str] = ...,
    ) -> None: ...

class ReactionsByFidRequest(_message.Message):
    __slots__ = ["fid", "reaction_type", "page_size", "page_token", "reverse"]
    FID_FIELD_NUMBER: _ClassVar[int]
    REACTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REVERSE_FIELD_NUMBER: _ClassVar[int]
    fid: int
    reaction_type: _message_pb2.ReactionType
    page_size: int
    page_token: bytes
    reverse: bool
    def __init__(
        self,
        fid: _Optional[int] = ...,
        reaction_type: _Optional[_Union[_message_pb2.ReactionType, str]] = ...,
        page_size: _Optional[int] = ...,
        page_token: _Optional[bytes] = ...,
        reverse: bool = ...,
    ) -> None: ...

class ReactionsByTargetRequest(_message.Message):
    __slots__ = [
        "target_cast_id",
        "target_url",
        "reaction_type",
        "page_size",
        "page_token",
        "reverse",
    ]
    TARGET_CAST_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_URL_FIELD_NUMBER: _ClassVar[int]
    REACTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REVERSE_FIELD_NUMBER: _ClassVar[int]
    target_cast_id: _message_pb2.CastId
    target_url: str
    reaction_type: _message_pb2.ReactionType
    page_size: int
    page_token: bytes
    reverse: bool
    def __init__(
        self,
        target_cast_id: _Optional[_Union[_message_pb2.CastId, _Mapping]] = ...,
        target_url: _Optional[str] = ...,
        reaction_type: _Optional[_Union[_message_pb2.ReactionType, str]] = ...,
        page_size: _Optional[int] = ...,
        page_token: _Optional[bytes] = ...,
        reverse: bool = ...,
    ) -> None: ...

class UserDataRequest(_message.Message):
    __slots__ = ["fid", "user_data_type"]
    FID_FIELD_NUMBER: _ClassVar[int]
    USER_DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    fid: int
    user_data_type: _message_pb2.UserDataType
    def __init__(
        self,
        fid: _Optional[int] = ...,
        user_data_type: _Optional[_Union[_message_pb2.UserDataType, str]] = ...,
    ) -> None: ...

class NameRegistryEventRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: bytes
    def __init__(self, name: _Optional[bytes] = ...) -> None: ...

class RentRegistryEventsRequest(_message.Message):
    __slots__ = ["fid"]
    FID_FIELD_NUMBER: _ClassVar[int]
    fid: int
    def __init__(self, fid: _Optional[int] = ...) -> None: ...

class OnChainEventRequest(_message.Message):
    __slots__ = ["fid", "event_type"]
    FID_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    fid: int
    event_type: _onchain_event_pb2.OnChainEventType
    def __init__(
        self,
        fid: _Optional[int] = ...,
        event_type: _Optional[_Union[_onchain_event_pb2.OnChainEventType, str]] = ...,
    ) -> None: ...

class OnChainEventResponse(_message.Message):
    __slots__ = ["events"]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[_onchain_event_pb2.OnChainEvent]
    def __init__(
        self,
        events: _Optional[
            _Iterable[_Union[_onchain_event_pb2.OnChainEvent, _Mapping]]
        ] = ...,
    ) -> None: ...

class StorageLimitsResponse(_message.Message):
    __slots__ = ["limits"]
    LIMITS_FIELD_NUMBER: _ClassVar[int]
    limits: _containers.RepeatedCompositeFieldContainer[StorageLimit]
    def __init__(
        self, limits: _Optional[_Iterable[_Union[StorageLimit, _Mapping]]] = ...
    ) -> None: ...

class StorageLimit(_message.Message):
    __slots__ = ["store_type", "limit"]
    STORE_TYPE_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    store_type: StoreType
    limit: int
    def __init__(
        self,
        store_type: _Optional[_Union[StoreType, str]] = ...,
        limit: _Optional[int] = ...,
    ) -> None: ...

class UsernameProofRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: bytes
    def __init__(self, name: _Optional[bytes] = ...) -> None: ...

class UsernameProofsResponse(_message.Message):
    __slots__ = ["proofs"]
    PROOFS_FIELD_NUMBER: _ClassVar[int]
    proofs: _containers.RepeatedCompositeFieldContainer[
        _username_proof_pb2.UserNameProof
    ]
    def __init__(
        self,
        proofs: _Optional[
            _Iterable[_Union[_username_proof_pb2.UserNameProof, _Mapping]]
        ] = ...,
    ) -> None: ...

class VerificationRequest(_message.Message):
    __slots__ = ["fid", "address"]
    FID_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    fid: int
    address: bytes
    def __init__(
        self, fid: _Optional[int] = ..., address: _Optional[bytes] = ...
    ) -> None: ...

class SignerRequest(_message.Message):
    __slots__ = ["fid", "signer"]
    FID_FIELD_NUMBER: _ClassVar[int]
    SIGNER_FIELD_NUMBER: _ClassVar[int]
    fid: int
    signer: bytes
    def __init__(
        self, fid: _Optional[int] = ..., signer: _Optional[bytes] = ...
    ) -> None: ...

class LinkRequest(_message.Message):
    __slots__ = ["fid", "link_type", "target_fid"]
    FID_FIELD_NUMBER: _ClassVar[int]
    LINK_TYPE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FID_FIELD_NUMBER: _ClassVar[int]
    fid: int
    link_type: str
    target_fid: int
    def __init__(
        self,
        fid: _Optional[int] = ...,
        link_type: _Optional[str] = ...,
        target_fid: _Optional[int] = ...,
    ) -> None: ...

class LinksByFidRequest(_message.Message):
    __slots__ = ["fid", "link_type", "page_size", "page_token", "reverse"]
    FID_FIELD_NUMBER: _ClassVar[int]
    LINK_TYPE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REVERSE_FIELD_NUMBER: _ClassVar[int]
    fid: int
    link_type: str
    page_size: int
    page_token: bytes
    reverse: bool
    def __init__(
        self,
        fid: _Optional[int] = ...,
        link_type: _Optional[str] = ...,
        page_size: _Optional[int] = ...,
        page_token: _Optional[bytes] = ...,
        reverse: bool = ...,
    ) -> None: ...

class LinksByTargetRequest(_message.Message):
    __slots__ = ["target_fid", "link_type", "page_size", "page_token", "reverse"]
    TARGET_FID_FIELD_NUMBER: _ClassVar[int]
    LINK_TYPE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    REVERSE_FIELD_NUMBER: _ClassVar[int]
    target_fid: int
    link_type: str
    page_size: int
    page_token: bytes
    reverse: bool
    def __init__(
        self,
        target_fid: _Optional[int] = ...,
        link_type: _Optional[str] = ...,
        page_size: _Optional[int] = ...,
        page_token: _Optional[bytes] = ...,
        reverse: bool = ...,
    ) -> None: ...

class IdRegistryEventRequest(_message.Message):
    __slots__ = ["fid"]
    FID_FIELD_NUMBER: _ClassVar[int]
    fid: int
    def __init__(self, fid: _Optional[int] = ...) -> None: ...

class IdRegistryEventByAddressRequest(_message.Message):
    __slots__ = ["address"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: bytes
    def __init__(self, address: _Optional[bytes] = ...) -> None: ...
